Index: hovertip.js
===================================================================
RCS file: /cvs/drupal-contrib/contributions/modules/hovertip/hovertip.js,v
retrieving revision 1.2
diff -u -r1.2 hovertip.js
--- hovertip.js	20 Feb 2007 15:21:28 -0000	1.2
+++ hovertip.js	16 Aug 2007 10:13:29 -0000
@@ -325,8 +325,8 @@
         else
           this.ht.targets.add(targetPrepare(targets, this, config));
         
-        // listen to mouse move events so we know exatly where to place hovetips
-        targets.mousemove(hovertipMouseUpdate);
+        // listen to mouseover events so we know exactly where to place hovertips
+        targets.mouseover(hovertipMouseUpdate);
         
         // prepare the tooltip element
         // is it bad form to call $(this) here?
